@@ -32,7 +32,9 @@ e_hal_property_string_get(E_Hal_Properties *properties, const char *key, int *er
 {
   E_Hal_Property *prop;
   if (err) *err = 0;
+  if (!properties) return NULL;
   if (!properties->properties) return NULL;
+  if (!key) return NULL;
   prop = eina_hash_find(properties->properties, key);
   if (prop) return prop->val.s;
 
@@ -45,12 +47,14 @@ e_hal_property_bool_get(E_Hal_Properties *properties, const char *key, int *err)
 {
   E_Hal_Property *prop;
   if (err) *err = 0;
-  if (!properties->properties) return 0;
+  if (!properties) return EINA_FALSE;
+  if (!properties->properties) return EINA_FALSE;
+  if (!key) return EINA_FALSE;
   prop = eina_hash_find(properties->properties, key);
   if (prop) return prop->val.b;
   
   if (err) *err = 1;
-  return 0;
+  return EINA_FALSE;
 }
 
 EAPI int
@@ -58,7 +62,9 @@ e_hal_property_int_get(E_Hal_Properties *properties, const char *key, int *err)
 {
   E_Hal_Property *prop;
   if (err) *err = 0;
+  if (!properties) return 0;
   if (!properties->properties) return 0;
+  if (!key) return 0;
   prop = eina_hash_find(properties->properties, key);
   if (prop) return prop->val.i;
 
@@ -71,7 +77,9 @@ e_hal_property_uint64_get(E_Hal_Properties *properties, const char *key, int *er
 {
   E_Hal_Property *prop;
   if (err) *err = 0;
+  if (!properties) return 0;
   if (!properties->properties) return 0;
+  if (!key) return 0;
   prop = eina_hash_find(properties->properties, key);
   if (prop) return prop->val.u64;
 
@@ -84,7 +92,9 @@ e_hal_property_double_get(E_Hal_Properties *properties, const char *key, int *er
 {
   E_Hal_Property *prop;
   if (err) *err = 0;
+  if (!properties) return 0;
   if (!properties->properties) return 0;
+  if (!key) return 0;
   prop = eina_hash_find(properties->properties, key);
   if (prop) return prop->val.d;
 
@@ -97,7 +107,9 @@ e_hal_property_strlist_get(E_Hal_Properties *properties, const char *key, int *e
 {
   E_Hal_Property *prop;
   if (err) *err = 0;
+  if (!properties) return NULL;
   if (!properties->properties) return NULL;
+  if (!key) return NULL;
   prop = eina_hash_find(properties->properties, key);
   if (prop) return prop->val.strlist;
 
